@@ -1,6 +1,6 @@
 // main.cpp
 //
-// Copyright (c) 2019-2023 Kristofer Berggren
+// Copyright (c) 2019-2024 Kristofer Berggren
 // All rights reserved.
 //
 // nmail is distributed under the MIT license, see LICENSE for details.
@@ -166,14 +166,16 @@ int main(int argc, char* argv[])
     { "smtp_port", "587" },
     { "smtp_user", "" },
     { "save_pass", "0" },
+    { "idle_inbox", "1" },
     { "inbox", "INBOX" },
     { "trash", "" },
     { "drafts", "" },
     { "sent", "" },
     { "addressbook_encrypt", "0" },
-    { "client_store_sent", "0" },
     { "cache_encrypt", "0" },
     { "cache_index_encrypt", "0" },
+    { "client_store_sent", "0" },
+    { "coredump_enabled", "0" },
     { "html_to_text_cmd", "" },
     { "text_to_html_cmd", "" },
     { "parts_viewer_cmd", "" },
@@ -259,6 +261,7 @@ int main(int argc, char* argv[])
   std::string drafts = mainConfig->Get("drafts");
   std::string sent = mainConfig->Get("sent");
   const bool clientStoreSent = (mainConfig->Get("client_store_sent") == "1");
+  const bool idleInbox = (mainConfig->Get("idle_inbox") == "1");
   Util::SetHtmlToTextConvertCmd(mainConfig->Get("html_to_text_cmd"));
   Util::SetTextToHtmlConvertCmd(mainConfig->Get("text_to_html_cmd"));
   Util::SetPartsViewerCmd(mainConfig->Get("parts_viewer_cmd"));
@@ -275,6 +278,7 @@ int main(int argc, char* argv[])
   Util::SetSendIp(mainConfig->Get("send_ip") == "1");
   Util::SetFilePickerCmd(mainConfig->Get("file_picker_cmd"));
   Util::SetDownloadsDir(mainConfig->Get("downloads_dir"));
+  const bool isCoredumpEnabled = (mainConfig->Get("coredump_enabled") == "1");
 
   // Set logging verbosity level based on config, if not specified with command line arguments
   if (Log::GetVerboseLevel() == Log::INFO_LEVEL)
@@ -289,6 +293,16 @@ int main(int argc, char* argv[])
     }
   }
 
+  // Init core dump
+  if (isCoredumpEnabled)
+  {
+#ifndef HAS_COREDUMP
+    LOG_WARNING("core dump not supported");
+#else
+    Util::InitCoredump();
+#endif
+  }
+
   // Crypto init
   Crypto::Init();
 
@@ -382,7 +396,8 @@ int main(int argc, char* argv[])
                                             std::placeholders::_2),
                                   std::bind(&Ui::StatusHandler, std::ref(ui), std::placeholders::_1),
                                   std::bind(&Ui::SearchHandler, std::ref(ui), std::placeholders::_1,
-                                            std::placeholders::_2));
+                                            std::placeholders::_2),
+                                  idleInbox, inbox);
 
   std::shared_ptr<SmtpManager> smtpManager =
     std::make_shared<SmtpManager>(smtpUser, smtpPass, smtpHost, smtpPort, name, address, online,
@@ -470,7 +485,7 @@ static void ShowVersion()
   std::cout <<
     Version::GetUiAppVersion() << "\n"
     "\n"
-    "Copyright (c) 2019-2023 Kristofer Berggren\n"
+    "Copyright (c) 2019-2024 Kristofer Berggren\n"
     "\n"
     "nmail is distributed under the MIT license.\n"
     "\n"
