@@ -1,6 +1,6 @@
 // util.cpp
 //
-// Copyright (c) 2019-2023 Kristofer Berggren
+// Copyright (c) 2019-2024 Kristofer Berggren
 // All rights reserved.
 //
 // nmail is distributed under the MIT license, see LICENSE for details.
@@ -25,6 +25,8 @@
 #include <unistd.h>
 #include <wordexp.h>
 
+#include <sys/resource.h>
+
 #ifdef __APPLE__
 #include <libproc.h>
 #endif
@@ -384,11 +386,6 @@ void Util::Move(const std::string& p_From, const std::string& p_To)
   apathy::Path::move(p_From, p_To);
 }
 
-void Util::Touch(const std::string& p_Path)
-{
-  utimensat(0, p_Path.c_str(), NULL, 0);
-}
-
 std::string Util::GetApplicationDir()
 {
   return m_ApplicationDir;
@@ -1389,7 +1386,9 @@ std::map<int, std::string> Util::GetCrashingSignals()
     { SIGSEGV, "SIGSEGV" },
     { SIGSYS, "SIGSYS" },
     { SIGTRAP, "SIGTRAP" },
+#ifdef HAS_THREADS_CRASH_STACKS
     { SIGUSR1, "SIGUSR1" },
+#endif
   };
   return crashingSignals;
 }
@@ -1488,13 +1487,16 @@ void Util::SignalCrashHandler(int p_Signal)
       std::cerr << logMsg << "\n" << callstackStr << "\n";
     }
 
+#ifdef HAS_THREADS_CRASH_STACKS
     if (Log::GetTraceEnabled())
     {
       ThreadRegister::SignalThreads(SIGUSR1);
       sleep(1);
     }
+#endif
 
-    exit(1);
+    signal(p_Signal, SIG_DFL);
+    kill(getpid(), p_Signal);
   }
   else
   {
@@ -2225,3 +2227,35 @@ void Util::RemoveNonAlphaNumSpace(std::string& p_Str)
 
   p_Str.erase(it, p_Str.end());
 }
+
+void Util::InitCoredump()
+{
+  struct rlimit lim;
+  int rv = 0;
+  rv = getrlimit(RLIMIT_CORE, &lim);
+  if (rv != 0)
+  {
+    LOG_WARNING("getrlimit failed %d errno %d", rv, errno);
+  }
+  else
+  {
+    lim.rlim_cur = lim.rlim_max;
+    rv = setrlimit(RLIMIT_CORE, &lim);
+    if (rv != 0)
+    {
+      LOG_WARNING("setrlimit failed %d errno %d", rv, errno);
+    }
+    else
+    {
+      LOG_DEBUG("setrlimit cur %llu max %llu", lim.rlim_cur, lim.rlim_max);
+    }
+  }
+
+#ifdef __APPLE__
+  rv = access("/cores", W_OK);
+  if (rv == -1)
+  {
+    LOG_WARNING("/cores is not writable");
+  }
+#endif
+}
